fn subject(document: &IndexedDocument<'_>, ops: &[OpCodes]) -> SaidExpand description
What ops acted on: the one entity where they agree on one, a count
otherwise.
fn subject(document: &IndexedDocument<'_>, ops: &[OpCodes]) -> SaidWhat ops acted on: the one entity where they agree on one, a count
otherwise.