pub enum Shape {
Block(BlockId),
Port(PinId),
Text(TextId),
Area(AreaId),
Image(ImageId),
Icon(BlockId),
}Expand description
What a drag grabbed. An icon is named by the block that owns it, as it has no id of its own.
Variants
Implementations