fn draw_arrowhead(
head: Pos2,
dir: Vec2,
color: Role,
painter: &Style<'_, impl Renderer>,
)Expand description
Draw a filled triangular arrowhead with its point at head, pointing in
dir.
fn draw_arrowhead(
head: Pos2,
dir: Vec2,
color: Role,
painter: &Style<'_, impl Renderer>,
)Draw a filled triangular arrowhead with its point at head, pointing in
dir.