pub fn fixed_corner(rect: &Rect, mode: ResizeMode) -> Pos2Expand description
The corner mode keeps fixed while resizing rect (opposite
resize_corner).
pub fn fixed_corner(rect: &Rect, mode: ResizeMode) -> Pos2The corner mode keeps fixed while resizing rect (opposite
resize_corner).