pub fn wire_label(
doc: &Document,
id: RouteLabelId,
route: RouteId,
pos: FracVal,
builder: &mut CommitBuilder,
)Expand description
Inventory row “Add Wire Label”: drop a name label on a wire, at the arc length the click projected onto its polyline.