fn title_target(id: ShapeId) -> Option<TitleTarget>Expand description
The entity a shape names to the delete cascade. An icon has none — it is a value on its block, not an entity, so it is zeroed rather than deleted.
fn title_target(id: ShapeId) -> Option<TitleTarget>The entity a shape names to the delete cascade. An icon has none — it is a value on its block, not an entity, so it is zeroed rather than deleted.